"use strict";
const pug = require("volar-service-pug/lib/languageService");
const source_map_1 = require("@volar/source-map");
const plugin = ({ modules }) => {
    return {
        name: require('./package.json').name,
        version: 2.1,
        compileSFCTemplate(lang, template, options) {
            if (lang === 'pug') {
                const pugFile = pug?.baseParse(template);
                const map = new source_map_1.SourceMap(pugFile.mappings);
                if (pugFile) {
                    const compiler = modules['@vue/compiler-dom'];
                    const completed = compiler.compile(pugFile.htmlCode, {
                        ...options,
                        comments: true,
                        onWarn(warning) {
                            options?.onWarn?.(createProxyObject(warning));
                        },
                        onError(error) {
                            options?.onError?.(createProxyObject(error));
                        },
                    });
                    return createProxyObject(completed);
                    function createProxyObject(target) {
                        return new Proxy(target, {
                            get(target, prop) {
                                if (prop === 'offset') {
                                    const htmlOffset = target.offset;
                                    const nums = [];
                                    for (const mapped of map.toSourceLocation(htmlOffset)) {
                                        nums.push(mapped[0]);
                                    }
                                    return Math.max(-1, ...nums);
                                }
                                const value = target[prop];
                                if (typeof value === 'object') {
                                    return createProxyObject(target[prop]);
                                }
                                return value;
                            }
                        });
                    }
                }
            }
        },
    };
};
module.exports = plugin;
//# sourceMappingURL=index.js.map